@@ -321,16 +321,16 @@ class Components:
                                 'font-size': '15px'}),
             ]),
 
-            dbc.Row(html.Div(title), style={'font-size': '11px'}),
+            dbc.Row(html.Div(title), style={'font-size': '11px','padding-left':'1px'}),
 
             html.Div(style={'height': '15px', }),
 
             html.Div('Performance', style={'color': 'Cyan', 'font-size': '15px'}),
-            html.Div(children=per_col1, style={'font-size': '11px'}),
+            html.Div(children=per_col1, style={'font-size': '11px','padding-left':'1px'}),
             html.Div(style={'height': '15px', }),
 
             html.Div('Comparison', style={'color': 'Cyan', 'font-size': '15px'}),
-            html.Div(children=per_col2, style={'font-size': '11px','padding-right': '10px'}),
+            html.Div(children=per_col2, style={'font-size': '11px','padding-right': '10px','padding-left':'1px'}),
             html.Div(style={'height': '15px', }),
 
             html.Div('Performance by Year', style={'color': 'Cyan', 'font-size': '15px'}),
@@ -799,11 +799,25 @@ class Components:
                 dict['path'] = equity_path
                 dict['parameters'] = parameters
                 dict['performance'] = {
-                    'initial_capital': "{:,}".format(int(row['initial'])),
-                    'return': "{:.0%}".format(row['return']/100),
-                    'mdd': "{:.0%}".format(row['mdd']/100),
+                    'initial_capital': row['initial'],
+                    'net_profit_to_mdd': row['net_profit_to_mdd'],
+                    'net_profit': row['net_profit'],
+                    'mdd_dollar': row['mdd_dollar'],
+                    'mdd_pct': row['mdd_pct'],
+                    'num_of_trade': row['num_of_trade'],
+                    'num_of_win': row['num_of_win'],
+                    'return_on_capital': row['return_on_capital'],
+                    'total_commission': row['total_commission'],
                     'sharp_ratio': row['sharp'],
                 }
+                start_date_year = datetime.datetime.strptime(parameters['startdate'], '%Y%m%d').year
+                end_date_year = datetime.datetime.strptime(parameters['enddate'], '%Y%m%d').year
+                year_list = list(range(start_date_year, end_date_year + 1))
+                for year in year_list:
+                    dict['performance'][f'{year}'] = row[f'{year}']
+                    dict['performance'][f'{year}'] = row[f'{year}']
+                    dict['performance'][f'{year}_win_count'] = row[f'{year}_win_count']
+
                 equity_curves.append(dict)
 
         line_colour = []
@@ -827,12 +841,32 @@ class Components:
 
             performance_text = []
             for key, value in df.iloc[i - 1].performance.items():
-                performance_text.append(html.Div(f'{key} : {value}',style={'line-height': line_height}))
+                if key == 'initial_capital':
+                    item = 'Initial Capital'
+                    _value = "{:,}".format(int(value))
+                    performance_text.append(html.Div(f'{item} : {_value}', style={'line-height': line_height}))
+
+                if key == 'num_of_trade':
+                    item = 'Number of Trade'
+                    _value = "{:,}".format(int(value))
+                    performance_text.append(html.Div(f'{item} : {_value}', style={'line-height': line_height}))
+
+                if key == 'mdd_pct':
+                    item = 'MDD Percentage'
+                    _value = "{:.0%}".format(value/100)
+                    performance_text.append(html.Div(f'{item} : {_value}', style={'line-height': line_height}))
+
+                if key == 'return_on_capital':
+                    item = 'Return on Capital'
+                    _value = "{:.0%}".format(value/100)
+                    performance_text.append(html.Div(f'{item} : {_value}', style={'line-height': line_height}))
+
+                # performance_text.append(html.Div(f'{key} : {value}',style={'line-height': line_height}))
 
             choices.append({
                 "label": html.Div([
 
-                    html.Div('----------------------------------------------------------------------------------'),
+                    html.Div('-----------------------------------------------------------------'),
 
                     dbc.Row([
                         dbc.Col([
@@ -883,7 +917,7 @@ class Components:
 
                     ]),
 
-                ],style={"display": "inline-block", 'width':'400px'}
+                ],style={"display": "inline-block", 'width':'320px'}
 
                 ),
 
@@ -907,7 +941,7 @@ class Components:
             dbc.Row([
                 html.Div(_checklist),
                 html.Div(style={'height': '5px'}),
-                html.Div('----------------------------------------------------------------------------------------------------',
+                html.Div('--------------------------------------------------------------------------------',
                          style={'padding-left': '23px'}),
                 html.Div(style={'height': '10px', }),
             ]), style={'padding': '0px', 'font-size': '12px'})
@@ -915,29 +949,90 @@ class Components:
         return df, row
 
 
-    def aggregate_performance(self, performance_list):
-        return_on_capital = "{:.1%}".format(performance_list[0])
-        annualized_return = "{:.1%}".format(performance_list[1])
-        annualized_sr = round(performance_list[2],2)
-        mdd_pct = "{:.1%}".format(performance_list[3])
+    def aggregate_performance(self, total_dict, year_list):
+        num_of_trade = "{:,}".format(int(total_dict['num_of_trade']))
+        net_profit = "{:,}".format(int(round(total_dict['net_profit'],0)) )
+        net_profit_to_mdd = round(total_dict['net_profit_to_mdd'],2)
+        win_rate = "{:.0%}".format(total_dict['win_rate'])
+
+        total_commission = "{:,}".format(int(total_dict['total_commission']))
+        return_on_capital = "{:.0%}".format(total_dict['return_on_capital'])
+        annualized_return = "{:.0%}".format(total_dict['annualized_return'])
+        annualized_std = "{:.0%}".format(total_dict['annualized_std'])
+        annualized_sr = round(total_dict['annualized_sr'],2)
+        mdd_dollar = "{:,}".format(int(total_dict['mdd_dollar']))
+        mdd_pct = "{:.0%}".format(total_dict['mdd_pct'])
+
+        year_col = []
+        year_count = []
+        year_count_col = []
+        year_win_rate_col = []
+        for year in year_list:
+            year_col.append(html.Div(year))
+            year_count.append(int(total_dict[f'{year}']))
+            year_count_col.append(html.Div(int(total_dict[f'{year}'])))
+            rate = total_dict[f'{year}_win_count']/total_dict[f'{year}']
+            year_win_rate_col.append(html.Div( "{:.0%}".format(rate) ))
+
+        cov = round(np.std(year_count) / np.mean(year_count), 2)
+
+
 
         div = html.Div([
+
+            html.Div('Performance', style={'color': 'Cyan', 'font-size': '15px'}),
+
+            html.Div(style={'height': '5px'}),
+
             dbc.Row([
-                dbc.Col('Return on Capital', width=2),
-                dbc.Col(return_on_capital, width=2),
+                dbc.Col([html.Div('Number of Trade'),
+                         html.Div('Net Profit'),
+                         html.Div('Net Profit/MDD Ratio'),
+                         html.Div('Win Rate'),
+                         html.Div('COV'),
+                         html.Div('Total Commission'),
+                         html.Div('Return on Capital'),
+                         html.Div('Ann. Return'),
+                         html.Div('Ann. Std'),
+                         html.Div('Ann. Sharp Ratio'),
+                         html.Div('MDD Dollar'),
+                         html.Div('MDD Percentage')],
+                        style={'padding-left':'13px'},
+                        width=7),
+                dbc.Col([html.Div(num_of_trade),
+                         html.Div(net_profit),
+                         html.Div(net_profit_to_mdd),
+                         html.Div(win_rate),
+                         html.Div(cov),
+                         html.Div(total_commission),
+                         html.Div(return_on_capital),
+                         html.Div(annualized_return),
+                         html.Div(annualized_std),
+                         html.Div(annualized_sr),
+                         html.Div(mdd_dollar),
+                         html.Div(mdd_pct),
+                         ],
+                        style={'text-align': 'center',},width=5),
             ]),
+
+            html.Div(style={'height': '10px'}),
+
+            html.Div('Performance by Year', style={'color': 'Cyan', 'font-size': '15px'}),
+
+            html.Div(style={'height': '5px'}),
+
             dbc.Row([
-                dbc.Col('Annualized Return', width=2),
-                dbc.Col(annualized_return, width=2),
-            ]),
+                dbc.Col(width=3),
+                dbc.Col('Year Count', style={'color': 'Yellow', 'font-size': '15px'},width=5),
+                dbc.Col('Win Rate', style={'color': 'Yellow', 'font-size': '15px'},width=4),
+            ], style={'text-align': 'center'}),
+
             dbc.Row([
-                dbc.Col('Sharp Ratio', width=2),
-                dbc.Col(annualized_sr, width=2),
-            ]),
-            dbc.Row([
-                dbc.Col('MDD Percentage', width=2),
-                dbc.Col(mdd_pct, width=2),
-            ]),
+                dbc.Col(year_col, width=3),
+                dbc.Col(year_count_col, width=5),
+                dbc.Col(year_win_rate_col, width=4),
+            ], style={'text-align': 'center'})
+
         ])
 
         return div
\ No newline at end of file
